==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/menu.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR);
$ret = KWL_MakeNavigator("b");
if (is_array($ret)) {
   $VAR['Content'] = "<FONT COLOR=\"$LAYOUT[NavColor]\">";
   foreach ($ret as $link) {
      $VAR['Content'] .= "$CONF[dotchar]" . $link . "<BR>\n";
   }
   $VAR['Content'] .= "</FONT>\n";
   $VAR['Heading'] =& htmlspecialchars($CONF['SiteName']);
   $VAR['Display'] =& $align;
   KWL_DrawBlock($VAR);
   $cnt++;
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/menu.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR);
$ret = KWL_MakeNavigator("b");
if (is_array($ret)) {
   $VAR['Content'] = "<font color=\"$LAYOUT[NavColor]\">";
   foreach ($ret as $link) {
      $VAR['Content'] .= "$CONF[dotchar]" . $link . "<br />\n";
   }
   $VAR['Content'] .= "</font>\n";
   $VAR['Heading'] =& htmlspecialchars($CONF['SiteName']);
   $VAR['Display'] =& $align;
   KWL_DrawBlock($VAR);
   $cnt++;
}
?>
